#!/tmp/abs_9dh6gj88e4/croots/recipe/gdal-split_1659452592616/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold/bin/python
# EASY-INSTALL-SCRIPT: 'GDAL==3.0.2','gdal_calc.py'
__requires__ = 'GDAL==3.0.2'
__import__('pkg_resources').run_script('GDAL==3.0.2', 'gdal_calc.py')
